@@ -12,16 +12,27 @@ extern "C" {
 }
 #endif
 
+MGVTBL inline_mg_vtbl = {
+    0x0,
+    0x0,
+    0x0,
+    0x0,
+    &free_inline_py_obj,
+    0x0,
+    0x0,
+    0x0
+};
+
 /*************************************
  *         UTILITY FUNCTIONS         *
  *************************************/
+
 int free_inline_py_obj(pTHX_ SV* obj, MAGIC *mg)
 {
     if (mg && mg->mg_type == PERL_MAGIC_ext && Inline_Magic_Check(mg->mg_ptr)) {
         IV const iv = SvIV(obj);
         /*Printf(("free_inline_py_obj: %p, iv: %p, ob_prev: %p, ob_next: %p, refcnt: %i\n", obj, iv, ((PyObject *)iv)->_ob_prev, ((PyObject *)iv)->_ob_next, ((PyObject *)iv)->ob_refcnt)); */ /* _ob_prev and _ob_next are only available if Python is compiled with reference debugging enabled */
         Printf(("free_inline_py_obj: %p, iv: %p, refcnt: %i\n", obj, iv, ((PyObject *)iv)->ob_refcnt));
-        free(mg->mg_virtual); /* allocated in Py2Pl */
         Py_XDECREF((PyObject *)iv); /* just in case */
     }
     else {
